
# Slot: genetic association


Co-occurrence of a certain allele of a genetic marker and the phenotype of interest in the same individuals at above-chance level

URI: [biolink:genetic_association](https://w3id.org/biolink/vocab/genetic_association)


## Domain and Range

[NamedThing](NamedThing.md) &#8594;  <sub>0..\*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children

 *  [condition associated with gene](condition_associated_with_gene.md)
 *  [gene associated with condition](gene_associated_with_condition.md)

## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Exact Mappings:** | | WIKIDATA_PROPERTY:P2293 |

